# 2021-12-08 - Aave Linear Pool

Deployment of the `AaveLinearPoolFactory`, for Linear Pools with a wrapped aToken.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [`AaveLinearPool` ABI](./abi/AaveLinearPool.json)
